# PROCESS GISETTE DATA - STAGE 2.

source("../../select.r")
source("../../pca.r")
source("../../plot.r")

# Find pvalues for tests of association of features with class. 

pval.perm.trim <- 
   perm.pval(train.trim,ranks=TRUE,perms=9999) # TAKES ABOUT 2.5 HOURS

pval.hyper.trim <- pmax (hyper.pval(train.n0[ix.trim],train.n1[ix.trim]), 1e-10)

pval.runs.trim <- runs.pval(train.trim)  # TAKES ABOUT 20 HOURS

# Produce various plots of p-values.

postscript("gisette2a.ps",horizontal=TRUE)

par(mfrow=c(2,3))

minp <- 0.01/length(ix.trim)

plot (pmax(minp,sort(pval.perm.trim)), pch=20, log="y", ylab="",
      xlab="Permutation test p-values", ylim=c(minp,1))
lines(1:length(ix.trim),((1:length(ix.trim))-0.5)/length(ix.trim))
abline(v=c(0,500,1000),lty=3)

plot (pmax(minp,sort(pval.hyper.trim)), pch=20, log="y", ylab="",
      xlab="Binary hypergeometric p-values", ylim=c(minp,1))
lines(1:length(ix.trim),((1:length(ix.trim))-0.5)/length(ix.trim))
abline(v=c(0,500,1000),lty=3)

plot (pmax(minp,sort(pval.runs.trim)), pch=20, log="y", ylab="", 
      xlab="Runs test p-values", ylim=c(minp,1))
lines(1:length(ix.trim),((1:length(ix.trim))-0.5)/length(ix.trim))
abline(v=c(0,500,1000),lty=3)

jitter <- exp(rnorm(length(ix.trim),0,0.05))

plot (pval.perm.trim*jitter, pval.hyper.trim*jitter, log="xy", pch=20,
      xlab="Permutation test p-values", ylab="Binary hypergeometric p-values")
abline(h=quantile(pval.hyper.trim,c(0.001,0.01,0.1)))
abline(v=quantile(pval.perm.trim,c(0.001,0.01,0.1)))

plot (pval.hyper.trim*jitter, pval.runs.trim*jitter, log="xy", pch=20,
      xlab="Binary hypergeometric p-values", ylab="Runs test p-values")
abline(h=quantile(pval.runs.trim,c(0.001,0.01,0.1)))
abline(v=quantile(pval.hyper.trim,c(0.001,0.01,0.1)))

plot (pval.runs.trim*jitter, pval.perm.trim*jitter, log="xy", pch=20,
      xlab="Runs test p-values", ylab="Permutation test p-values")
abline(h=quantile(pval.perm.trim,c(0.001,0.01,0.1)))
abline(v=quantile(pval.runs.trim,c(0.001,0.01,0.1)))

dev.off()

# Select a set of features using these pvalues.

sel.hyper <- order(pval.hyper.trim)[1:1085] # p-value <= 1e-10
sel.runs <- order(pval.runs.trim)[1:876]   # p-value <= 0.002
sel <- union(sel.hyper,sel.runs)
ix.sel <- ix.trim[sel]

write.ix(ix.sel,"sel")
write.data(ix.sel,"sel")

# Find the first 40 principle components from the trimmed set of features.
# Finds the principle components using the training data only to save time 
# and memory.

rm(train.x,valid.x,test.x)

pca.trim <- 
 pca.vectors (train.trim, 40, center=TRUE, scale=TRUE) # TAKES ABOUT 40 MINUTES
                                                    # REQUIRES ABOUT 1.6 GBYTES

write.pca (pca.trim, "pc", train.trim, valid.trim, test.trim)
